HiPSCat - Hierarchical Progressive Survey Catalog
========================================================================================

.. toctree::
   :maxdepth: 1
   :caption: Overview

   guide/directory_scheme
   Notebooks <notebooks>

.. toctree::
   :maxdepth: 1
   :caption: Developers

   guide/contributing
   Pixel math <guide/pixel_math>
   API Reference <autoapi/index>

Acknowledgements
-------------------------------------------------------------------------------

This project is supported by Schmidt Sciences.

This project is based upon work supported by the National Science Foundation
under Grant No. AST-2003196.

This project acknowledges support from the DIRAC Institute in the Department of 
Astronomy at the University of Washington. The DIRAC Institute is supported 
through generous gifts from the Charles and Lisa Simonyi Fund for Arts and 
Sciences, and the Washington Research Foundation.